@@ -3,6 +3,7 @@
 from constructor_io import __version__
 from constructor_io.helpers.exception import ConstructorException
 from constructor_io.modules.autocomplete import Autocomplete
+from constructor_io.modules.browse import Browse
 from constructor_io.modules.search import Search
 
 
@@ -41,6 +42,7 @@ class ConstructorIO:
 
         self.autocomplete = Autocomplete(self.__options)
         self.search = Search(self.__options)
+        self.browse = Browse(self.__options)
 
     def get_options(self):
         '''Get client options'''
